Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Lease ¶
type Lease struct {
ID bson.ObjectId `bson:"_id"`
Name string `bson:"name"`
Tags []string `bson:"tags"`
Metadata interface{} `bson:"metadata"`
Subnet bson.ObjectId `bson:"subnet,omitempty"`
Reservation bson.ObjectId `bson:"reservation,omitempty"`
Address bson.Binary `bson:"address"`
}
Lease is a mgo model representing a collection of Subnet resources.
type Pool ¶
type Pool struct {
ID bson.ObjectId `bson:"_id"`
Name string `bson:"name"`
Tags []string `bson:"tags"`
Metadata interface{} `bson:"metadata"`
}
Pool is a mgo model representing a collection of Subnet resources.
type Reservation ¶
type Reservation struct {
ID bson.ObjectId `bson:"_id"`
Name string `bson:"name"`
Tags []string `bson:"tags"`
Metadata interface{} `bson:"metadata"`
Subnet bson.ObjectId `bson:"subnet,omitempty"`
}
Reservation is a mgo model representing a collection of Subnet resources.
type Subnet ¶
type Subnet struct {
ID bson.ObjectId `bson:"_id"`
Name string `bson:"name"`
Tags []string `bson:"tags"`
Metadata interface{} `bson:"metadata"`
Pool bson.ObjectId `bson:"pool,omitempty"`
Start bson.Binary `bson:"start"`
End bson.Binary `bson:"end"`
}
Subnet is a mgo model representing a collection of Subnet resources.
Click to show internal directories.
Click to hide internal directories.